<?php
// Do not allow directly accessing this file.
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;

if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Direct script access denied.' );
}
if ( ! class_exists( 'G5Core_Elements_Listing_Abstract', false ) ) {
	G5CORE()->load_file(G5CORE()->plugin_dir('inc/abstract/elementor-listing.class.php'));
}
abstract class G5Staff_Abstracts_Elements_Listing extends G5Core_Elements_Listing_Abstract {


	protected function register_layout_section_controls() {
		$this->start_controls_section(
			'section_layout',
			[
				'label' => esc_html__( 'Layout', 'g5-staff' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->register_layout_controls();
		$this->register_skin_controls();
		$this->register_item_custom_class_controls();
		$this->register_single_link_controls();
		$this->register_excerpt_controls();
		$this->register_social_profiles_controls();
		$this->register_columns_controls();
		$this->register_columns_gutter_controls();
		$this->register_post_count_control();
		$this->register_post_offset_control();
		$this->register_post_paging_controls();
		$this->register_post_animation_controls();
		$this->register_cate_filter_controls();
		$this->end_controls_section();
	}


	protected function register_layout_controls() {
		$this->add_control(
			'post_layout',
			[
				'type' => Controls_Manager::SELECT,
				'label' => esc_html__('Post Layout','g5-staff'),
				'description' => esc_html__('Specify your staff layout','g5-staff'),
				'options' => $this->get_config_staff_layout(),
				'default' => 'grid',
			]
		);
	}

	protected function register_skin_controls() {
		$this->add_control(
			'item_skin',
			[
				'type' => Controls_Manager::SELECT,
				'label' => esc_html__('Item Skin', 'g5-staff'),
				'description' => esc_html__('Specify your staff item skin', 'g5-staff'),
				'options' => $this->get_config_staff_skins(),
				'default' => 'skin-01'
			]
		);
	}

	protected function register_single_link_controls() {
		$this->add_control(
			'single_link_disable',
			[
				'label' => esc_html__( 'Hide Single Link', 'g5-staff' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'g5-staff' ),
				'label_off' => esc_html__( 'No', 'g5-staff' ),
				'return_value' => 'on',
				'default' => '',
			]
		);
	}

	protected function register_excerpt_controls() {
		$this->add_control(
			'excerpt_enable',
			[
				'label' => esc_html__( 'Show Excerpt', 'g5-staff' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'g5-staff' ),
				'label_off' => esc_html__( 'Hide', 'g5-staff' ),
				'return_value' => 'on',
				'default' => '',
			]
		);
	}

	protected function register_social_profiles_controls() {
		$this->add_control(
			'social_profiles_enable',
			[
				'label' => esc_html__( 'Show Social Profiles', 'g5-staff' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'g5-staff' ),
				'label_off' => esc_html__( 'Hide', 'g5-staff' ),
				'return_value' => 'on',
				'default' => 'on',
			]
		);
	}


	protected function register_query_section_controls() {
		$this->start_controls_section(
			'section_query',
			[
				'label' => esc_html__( 'Query', 'g5-staff' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);



		$this->add_control(
			'show',
			[
				'type' => Controls_Manager::SELECT,
				'label' => esc_html__('Show', 'g5-staff'),
				'options' => [
					'' => esc_html__('All', 'g5-staff'),
					'new-in' => esc_html__('New In', 'g5-staff'),
					'staff' => esc_html__('Narrow Staff', 'g5-staff')
				],
				'default' => ''
			]

		);

		$this->register_cat_controls();
		$this->register_staff_ids_controls();
		$this->register_order_by_controls();
		$this->register_order_controls();
		$this->end_controls_section();
	}

	protected function register_image_size_section_controls() {
		parent::register_image_size_section_controls();
		$this->remove_control('post_image_width');
	}

	protected function register_cat_controls() {
		$this->add_control(
			'cat',
			[
				'type' => UBE_Controls_Manager::AUTOCOMPLETE,
				'multiple' => true,
				'select_type' => 'term',
				'data_args' => array(
					'taxonomy' => 'staff_group'
				),
				'label' => esc_html__('Narrow Groups','g5-staff'),
				'label_block' => true,
				'description' => esc_html__('Enter groups by names to narrow output.', 'g5-staff'),
				'default' => '',
				'condition' => [
					'show!' => 'staff',
				],
			]
		);
	}



	protected function register_staff_ids_controls() {
		$this->add_control(
			'ids',
			[
				'type' => UBE_Controls_Manager::AUTOCOMPLETE,
				'multiple' => true,
				'data_args' => array(
					'post_type' => 'staff'
				),
				'label' => esc_html__('Narrow Staff','g5-staff'),
				'label_block' => true,
				'description' => esc_html__('Enter List of Staff', 'g5-staff'),
				'default' => '',
				'condition' => [
					'show' => 'staff',
				],
			]
		);

	}

	protected function register_order_by_controls() {
		$this->add_control(
			'orderby',
			[
				'type' => Controls_Manager::SELECT,
				'label' => esc_html__('Order by', 'g5-staff'),
				'description' => esc_html__('Select how to sort retrieved staff.', 'g5-staff'),
				'options'     => G5STAFF()->settings()->get_staff_orderby(),
				'default' => 'date',
				'condition' => [
					'show' => [''],
				],
			]
		);
	}

	protected function register_order_controls() {
		$this->add_control(
			'order',
			[
				'type' => Controls_Manager::SELECT,
				'label' => esc_html__('Sorting', 'g5-staff'),
				'description' => esc_html__('Select sorting order.', 'g5-staff'),
				'options'     => array(
					'DESC' => esc_html__('Descending', 'g5-staff'),
					'ASC' => esc_html__('Ascending', 'g5-staff'),
				),
				'default' => 'DESC',
				'condition' => [
					'show' => [''],
				],
			]
		);
	}


	protected function register_style_section_controls() {
		$this->register_style_title_section_controls();
		$this->register_style_job_title_section_controls();
		$this->register_style_social_section_controls();
		$this->register_style_excerpt_section_controls();
	}

	protected function register_style_title_section_controls() {
		$this->start_controls_section(
			'section_design_title',
			[
				'label' => esc_html__( 'Title', 'g5-staff' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'selector' => '{{WRAPPER}} .g5staff__post-title',
			]
		);

		$this->add_control(
			'title_spacing',
			[
				'label' => esc_html__( 'Spacing', 'g5-staff' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .g5staff__post-title' => 'margin-top: {{SIZE}}{{UNIT}};',
				]
			]
		);

		$this->start_controls_tabs( 'title_color_tabs' );

		$this->start_controls_tab( 'title_color_normal',
			[
				'label' => esc_html__( 'Normal', 'g5-staff' ),
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Color', 'g5-staff' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .g5staff__post-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab( 'title_color_hover',
			[
				'label' => esc_html__( 'Hover', 'g5-staff' ),
			]
		);


		$this->add_control(
			'title_hover_color',
			[
				'label' => esc_html__( 'Color', 'g5-staff' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .g5staff__post-title:hover' => 'color: {{VALUE}};',
				],
			]
		);


		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();
	}

	protected function register_style_job_title_section_controls() {
		$this->start_controls_section(
			'section_design_job_title',
			[
				'label' => esc_html__( 'Job Title', 'g5-staff' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'job_title_typography',
				'selector' => '{{WRAPPER}} .g5staff__loop-job-title',
			]
		);

		$this->add_control(
			'job_title_spacing',
			[
				'label' => esc_html__( 'Spacing', 'g5-staff' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .g5staff__loop-job-title' => 'margin-bottom: {{SIZE}}{{UNIT}};margin-top: {{SIZE}}{{UNIT}};',

				]
			]
		);

		$this->add_control(
			'job_title_color',
			[
				'label' => esc_html__( 'Color', 'g5-staff' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .g5staff__loop-job-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}


	protected function register_style_social_section_controls() {
		$this->start_controls_section(
			'section_design_social',
			[
				'label' => esc_html__( 'Social', 'g5-staff' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'social_typography',
				'selector' => '{{WRAPPER}} .g5staff__loop-social-profiles',
			]
		);

		$this->add_control(
			'social_spacing',
			[
				'label' => esc_html__( 'Spacing', 'g5-staff' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .g5staff__loop-social-profiles' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				]
			]
		);

		$this->start_controls_tabs( 'social_color_tabs' );

		$this->start_controls_tab( 'social_color_normal',
			[
				'label' => esc_html__( 'Normal', 'g5-staff' ),
			]
		);

		$this->add_control(
			'social_color',
			[
				'label' => esc_html__( 'Color', 'g5-staff' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .g5staff__loop-social-profiles' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab( 'social_color_hover',
			[
				'label' => esc_html__( 'Hover', 'g5-staff' ),
			]
		);


		$this->add_control(
			'social_hover_color',
			[
				'label' => esc_html__( 'Color', 'g5-staff' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .g5staff__loop-social-profiles li:hover' => 'color: {{VALUE}};',
				],
			]
		);


		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();
	}

	protected function register_style_excerpt_section_controls() {
		$this->start_controls_section(
			'section_design_excerpt',
			[
				'label' => esc_html__( 'Excerpt', 'g5-staff' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'excerpt_enable' => 'on',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'excerpt_typography',
				'selector' => '{{WRAPPER}} .g5staff__post-excerpt',
			]
		);

		$this->add_control(
			'excerpt_color',
			[
				'label' => esc_html__( 'Color', 'g5-staff' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .g5staff__post-excerpt' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}

	public function get_config_staff_layout()
	{
		$config = apply_filters('g5staff_elementor_post_layout', array(
			'grid' => array(
				'label' => esc_html__('Grid', 'g5-staff'),
				'priority' => 10,
			),
		));

		uasort( $config, 'g5core_sort_by_order_callback' );


		$result = array();
		foreach ($config as $k => $v) {
			$result[$k] = $v['label'];
		}
		return $result;

	}

	public function get_config_post_slider_layout()
	{

		$config = apply_filters('g5staff_elementor_post_slider_layout', array(
			'grid' => array(
				'label' => esc_html__('Grid', 'g5-staff'),
				'priority' => 10,
			),
		));

		uasort( $config, 'g5core_sort_by_order_callback' );


		$result = array();
		foreach ($config as $k => $v) {
			$result[$k] = $v['label'];
		}
		return $result;
	}

	public function get_config_staff_skins() {

		$config = apply_filters('g5staff_elementor_staff_skins', array(
			'skin-01' => array(
				'label' => esc_html__('Skin 01', 'g5-staff'),
				'priority' => 10,
			),
			'skin-02' => array(
				'label' => esc_html__('Skin 02', 'g5-staff'),
				'priority' => 20,
			),
		));
		uasort( $config, 'g5core_sort_by_order_callback' );
		$result = array();
		foreach ($config as $k => $v) {
			$result[$k] = $v['label'];
		}
		return $result;
	}

}
