<?php
// Do not allow directly accessing this file.
if (!defined('ABSPATH')) {
	exit('Direct script access denied.');
}
if (!class_exists('G5Staff_Elementor')) {
	class G5Staff_Elementor {
		private static $_instance;
		public static function getInstance()
		{
			if (self::$_instance == NULL) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}

		public function init() {
			add_filter('ube_get_element_configs',array($this,'change_ube_get_element_configs'));
			add_filter('ube_autoload_file_dir',array($this,'change_ube_autoload_file_dir'),10,2);
			add_filter('ube_element_listing_query_args',array($this,'set_query_args'),10,2);
			add_action( 'init', array( $this, 'register_scripts' ) );
		}

		private function get_elements() {
			return apply_filters('g5staff_elements',array(
				'Staff' => esc_html__('Staff','g5-staff'),
				'Staff_Slider' => esc_html__('Staff Slider','g5-staff'),
			));
		}


		public function change_ube_get_element_configs($configs) {
			$elements = $this->get_elements();

			$g5_elements = isset($configs['g5_elements']) ? $configs['g5_elements'] : array(
				'title' => esc_html__('G5 Elements', 'g5-staff'),
				'items' => array()
			);

			foreach ($elements as $k => $v) {
				$g5_elements['items']["G5Staff_{$k}"] = array(
					'title' => $v
				);
			}

			$configs['g5_elements'] = $g5_elements;
			return $configs;
		}

		public function change_ube_autoload_file_dir($path, $class) {
			$prefix = 'UBE_Element_G5Staff_';
			if (strpos($class,$prefix) === 0) {
				$file_name = substr($class,strlen($prefix));
				$file_name = str_replace( '_', '-', $file_name );
				$file_name = strtolower( $file_name );
				return G5STAFF()->locate_template("elements/$file_name/config.php");
			}
			return $path;
		}

		public function register_scripts() {
			wp_register_script(G5STAFF()->assets_handle('staff-slider'),G5STAFF()->asset_url('assets/js/elements/staff-slider.min.js'),array(),G5STAFF()->plugin_ver());
			wp_register_script(G5STAFF()->assets_handle('staff'),G5STAFF()->asset_url('assets/js/elements/staff.min.js'),array(),G5STAFF()->plugin_ver());
		}

		public function set_query_args($query_args,$atts) {
			if ($query_args['post_type'] === 'staff') {
				$query_args['meta_query'] = array();
				$query_args['tax_query'] = array(
					'relation' => 'AND',
				);

				if (!isset($atts['show'])) {
					$atts['show'] = '';
				}

				switch ( $atts['show'] ) {
					case 'new-in':
						$query_args['orderby'] = 'date';
						$query_args['order'] = 'DESC';
						break;
					case 'staff':
						$query_args['post__in'] = array_map('absint',$atts['ids']);
						$query_args['posts_per_page'] = -1;
						$query_args['orderby'] = 'post__in';
						break;
				}

				if ($atts['show'] !== 'staff' && !empty($atts['cat'])) {
					$query_args['tax_query'][] = array(
						'taxonomy' => 'staff_group',
						'terms' => array_map('absint',$atts['cat']),
						'field' => 'id',
						'operator' => 'IN'
					);
				}

			}

			return $query_args;
		}
	}
}